@@ -16,7 +16,7 @@ class AbstractObject(object):
             self.stdout = VerbosePrint(verbosity)
         
             
-    def set_verbosity(verbosity:Optional[Union[int, str]]):
+    def set_verbosity(self, verbosity:Optional[Union[int, str]]):
         """
             Change the verbosity of the current class. This will detach the class's standard output 
             from the centrally-managed standard output.
