@@ -2,11 +2,13 @@ from typing import Optional, List, Dict
 import fnmatch
 import os
 import re
-import ROOT
+import json
 
 import numpy as np
 import pandas as pd
 
+import ROOT
+
 class RooProcBaseAction(object):
     def __init__(self, **params):
         self._params = params
@@ -121,7 +123,7 @@ class RooProcExport(RooProcHelperAction):
         return cls(**kwargs)
     
     def _execute(self, processor, **params):
-        filename = kwargs['filename']
+        filename = params['filename']
         data = {k:v.GetValue() for k,v in processor.external_variables.items()}
         dirname = os.path.dirname(filename)
         if dirname and (not os.path.exists(dirname)):
@@ -151,6 +153,26 @@ class RooProcGlobalVariables(RooProcHelperAction):
         processor.global_variables.update(params)
         return processor
     
+class RooProcAlias(RooProcRDFAction):
+    
+    def __init__(self, alias:str, column_name:str):
+        super().__init__(alias=alias, column_name=column_name)
+        
+    @classmethod
+    def parse(cls, text):
+        result = re.search(r"^\s*(\w+)\s*=\s*([\w\.]+)", text)
+        if not result:
+            raise RuntimeError(f"invalid expression {text}")
+        alias = result.group(1)
+        column_name = result.group(2)
+        return cls(alias=alias, column_name=column_name)        
+        
+    def _execute(self, rdf, **params):
+        alias = params['alias']
+        column_name = params['column_name']
+        rdf_next = rdf.Alias(alias, column_name)
+        return rdf_next    
+    
 class RooProcDefine(RooProcRDFAction):
     
     def __init__(self, name:str, expression:str):
@@ -284,11 +306,10 @@ class RooProcReport(RooProcHybridAction):
             df.to_csv(filename)
         return rdf, processor
     
-class RooProcSum(RooProcHybridAction):
+class RooProcStat(RooProcHybridAction):
     def __init__(self, ext_var_name:str, column_name:str):
         super().__init__(ext_var_name=ext_var_name,
                          column_name=column_name)
-        
     @classmethod
     def parse(cls, text):
         name_literals = re.findall(r"@{([^{}]+)}", text)
@@ -296,14 +317,33 @@ class RooProcSum(RooProcHybridAction):
             ext_var_name = name_literals[0]
             column_name = text.replace("@{" + ext_var_name + "}", "").strip()
         else:
-            raise RuntimeError("unspecified external variable name (format:@{ext_var_name})")
+            raise RuntimeError(f"unspecified external variable name (format:@{{ext_var_name}}): {text}")
         return cls(ext_var_name=ext_var_name, column_name=column_name)
+    
+    def _get_func(self, rdf):
+        raise NotImplementedError
         
     def _execute(self, rdf, processor, **params):
         ext_var_name = params['ext_var_name']
         column_name = params['column_name']
-        processor.external_variables[ext_var_name] = rdf.Sum(column_name)
+        processor.external_variables[ext_var_name] = self._get_func(rdf)(column_name)
         return rdf, processor
+    
+class RooProcSum(RooProcStat):
+    def _get_func(self, rdf):
+        return rdf.Sum
+    
+class RooProcMax(RooProcStat):
+    def _get_func(self, rdf):
+        return rdf.Max
+    
+class RooProcMin(RooProcStat):
+    def _get_func(self, rdf):
+        return rdf.Min
+    
+class RooProcMean(RooProcStat):
+    def _get_func(self, rdf):
+        return rdf.Mean
         
 class RooProcDeclare(RooProcHelperAction):
     
@@ -372,11 +412,15 @@ ACTION_MAP = {
     'TREENAME': RooProcTreeName,
     'DECLARE': RooProcDeclare,
     'GLOBAL': RooProcGlobalVariables,
+    'ALIAS': RooProcAlias,
     'DEFINE': RooProcDefine,
     'FILTER': RooProcFilter,
     'SAVE': RooProcSave,
     'REPORT': RooProcReport,
     'GETSUM': RooProcSum,
+    'GETMAX': RooProcMax,
+    'GETMIN': RooProcMin,
+    'GETMEAN': RooProcMean,
     'EXPORT': RooProcExport,
     'SAVE_FRAME': RooProcSaveFrame,
     'LOAD_FRAME': RooProcLoadFrame,
