@@ -38,7 +38,6 @@ class ToyLimitCalculator(AbstractObject):
                  mode:str='toy',
                  use_custom_teststat_cls:bool=True):
         super().__init__(verbosity=verbosity)
-        
         self.model_base = ExtendedModel(filename,
                                         data_name=data_name,
                                         snapshot_name=snapshot_name,
@@ -395,8 +394,8 @@ def evaluate_toy_limits(filename:str, data_name:str,
                         outname:str="toy_result_seed_{seed}.root",
                         poi_name:Optional[str]=None,
                         minimizer_type:str="Minuit2", strategy:int=1,
-                        eps:float=0.05, tolerance:float=1., print_level:int=-1,
-                        do_coarse_scan:bool=False, 
+                        eps:float=0.05, tolerance:float=1., offset:bool=True,
+                        print_level:int=-1, do_coarse_scan:bool=False, 
                         fix_param:str='', profile_param:str='',
                         snapshot_name:Optional[Union[List[str], str]]=None,                 
                         verbosity:Optional[Union[int, str]]=None):
@@ -409,6 +408,7 @@ def evaluate_toy_limits(filename:str, data_name:str,
                                               minimizer_type=minimizer_type,
                                               strategy=strategy,
                                               eps=eps, tolerance=tolerance,
+                                              offset=offset,
                                               print_level=print_level,
                                               do_coarse_scan=do_coarse_scan,
                                               fix_param=fix_param,
@@ -432,9 +432,9 @@ def evaluate_batched_toy_limits(filename:str, data_name:str,
                                 poi_min:Optional[float]=None, poi_max:Optional[float]=None,
                                 n_toys:int=1000, batchsize:int=100, seed:int=1234, 
                                 outname:str="toy_result_seed_{seed}_batch_{batch}.root",
-                                poi_name:Optional[str]=None,
-                                minimizer_type:str="Minuit2", strategy:int=1,
-                                eps:float=0.05, tolerance:float=1., print_level:int=-1,
+                                poi_name:Optional[str]=None, minimizer_type:str="Minuit2", 
+                                strategy:int=1, eps:float=0.05, tolerance:float=1., 
+                                offset:bool=True, print_level:int=-1,
                                 do_coarse_scan:bool=False, parallel:int=-1,
                                 fix_param:str='', profile_param:str='',
                                 snapshot_name:Optional[Union[List[str], str]]=None,                 
@@ -454,7 +454,7 @@ def evaluate_batched_toy_limits(filename:str, data_name:str,
     args = (repeat(filename), repeat(data_name), repeat(scan_min), repeat(scan_max),
             repeat(steps), repeat(mu_val), repeat(poi_min), repeat(poi_max),
             toy_batches, seeds, outnames, repeat(poi_name), repeat(minimizer_type), 
-            repeat(strategy), repeat(eps), repeat(tolerance), repeat(print_level),
-            repeat(do_coarse_scan), repeat(fix_param), repeat(profile_param),
-            repeat(snapshot_name), repeat(verbosity))
+            repeat(strategy), repeat(eps), repeat(tolerance), repeat(offset),
+            repeat(print_level), repeat(do_coarse_scan), repeat(fix_param), 
+            repeat(profile_param), repeat(snapshot_name), repeat(verbosity))
     execute_multi_tasks(evaluate_toy_limits, *args, parallel=parallel)
\ No newline at end of file
