@@ -13,7 +13,7 @@ import matplotlib.transforms as transforms
 from matplotlib.patches import Rectangle
 from matplotlib.backends.backend_pdf import PdfPages
 from quickstats.utils.process_tools import parallel_run
-from quickstats.plots.template import draw_ATLAS_label, format_axis_ticks, parse_transform, draw_hatches, \
+from quickstats.plots.template import draw_atlas_label, format_axis_ticks, parse_transform, draw_hatches, \
                                       draw_sigma_bands, draw_sigma_lines, get_box_dimension, draw_text, centralize_axis
 from quickstats.components.numerics import ceildiv, pretty_float
 from quickstats.utils.common_utils import json_load
@@ -63,8 +63,8 @@ BASE_STYLE = {
     },    
     'label':{
         'x': 0.02,
-        'dy': 0.01,
-        'fontsize': 15
+        'dy': 0.03,
+        'fontsize': 20
     },
     'figure': {
         'width' : 8,
@@ -430,34 +430,49 @@ class NPRankingPlot:
         axis.set_ylim((-padding, n + height/2))
     
     def draw_labels(axis, extra_text:str=None, elumi_label:bool=True, ranking_label:bool=True, height=1.0,
-                    energy:float=13, lumi:float=139, r_start:int=0, r_end:int=0, **styles):
+                    energy:float=13, lumi:float=139, status:str='int', r_start:int=0, r_end:int=0, **styles):
         """
             extra_text: extra labels below the ATLAS label, use "//" as newline delimiter
         """
-        x_logo = styles['logo']['x']
+        
+        dy            = styles['label']['dy'] 
+        x_logo        = styles['logo']['x']
         fontsize_logo = styles['logo']['fontsize']
-        _, _, y_curr, _ = draw_ATLAS_label(axis, x=x_logo, y=-height, transform_y='data', fontsize=fontsize_logo)
-        dy = styles['label']['dy']        
-        x_label = styles['label']['x']
+        
         text_options = {
             'fontsize'  : styles['label']['fontsize'],
-            'transform' : axis.transAxes,
-            'horizontalalignment': 'left',
-            'verticalalignment': 'top'
         }
-        texts = []
-        if extra_text is not None:
-            texts += extra_text.split("//")
-        if elumi_label:
-            energy = pretty_float(energy)
-            lumi = pretty_float(lumi)
-            s = r'$\sqrt{s}$' + ' = {} TeV, {} '.format(energy, lumi) + r'fb$^{-1}$'
-            texts.append(s)
+        
+        extra_texts = []
+        
+        if extra_text:
+            extra_texts.append(extra_texts)
+            
         if ranking_label:
-            s = 'Rank {} to {}'.format(r_start, r_end)
-            texts.append(s)
-        for text in texts:
-            _, _, y_curr, _ = draw_text(axis, x_label, y_curr - dy, text, **text_options)
+            rank_text = 'Rank {} to {}'.format(r_start, r_end)
+            extra_texts.append(rank_text)
+        
+        
+        draw_options = {
+            'axis': axis,
+            'loc': (x_logo, -height),
+            'fontsize': fontsize_logo,
+            'status': status,
+            'extra_text': "//".join(extra_texts),
+            'dy': dy,
+            'transform_y': 'data',            
+            'text_options': text_options,
+        }
+    
+        if not elumi_label:
+            draw_options['energy'] = None
+            draw_options['lumi'] = None
+        else:
+            draw_options['energy'] = energy
+            draw_options['lumi'] = lumi
+          
+        draw_atlas_label(**draw_options)
+        
     @staticmethod
     def parse_style(style:str):
         if os.path.exists(style):
@@ -475,8 +490,8 @@ class NPRankingPlot:
     def _plot(data, show_sigma:bool=True, show_prefit:bool=True, show_postfit:bool=True, sigma_bands:bool=False,
               sigma_lines:bool=True, shade:bool=True, correlation:bool=True, onesided:bool=True, relative:bool=False,
               theta_max:float=2, padding:int=7, height:float=1, spacing:float=0, display_poi:str=r"$\mu$", 
-              extra_text:str=None, elumi_label:bool=True, ranking_label:bool=True, energy:float=13, lumi:float=139, 
-              r_start:int=1, style:Dict=DEFAULT_STYLE):
+              extra_text:str=None, elumi_label:bool=True, ranking_label:bool=True, energy:str=r"13 TeV", 
+              lumi:str=r"139 fb$^{-1}$", status:str='int', r_start:int=1, style:Dict=DEFAULT_STYLE):
         # setup figure and axes
         plt.clf()
         fig_width, fig_height = style['figure']['width'], style['figure']['height']
@@ -508,11 +523,12 @@ class NPRankingPlot:
         NPRankingPlot.draw_np_labels(ax2, data, padding=padding, height=height)
         format_axis_ticks(ax1, y_axis=False, x_axis_styles=style['xaxis'])
         format_axis_ticks(ax2, y_axis=False, x_axis_styles=style['xaxis'])
+        ax2.xaxis.set_ticks_position('top')
         impact_xlim = ax2.get_xlim()
         if (abs(impact_xlim[0]) + abs(impact_xlim[1])) < 0.05:
             ax2.xaxis.set_major_locator(plt.MaxNLocator(3))        
         NPRankingPlot.draw_labels(ax1, extra_text=extra_text, height=height, elumi_label=elumi_label,
-                                  ranking_label=ranking_label, energy=energy, lumi=lumi, 
+                                  ranking_label=ranking_label, energy=energy, lumi=lumi, status=status,
                                   r_start=r_start, r_end=r_start + n - 1, **style)
         x_legend = style['legend']['x']
         NPRankingPlot.draw_legend(ax1, display_poi, x=x_legend, y=-1.2*height, show_prefit=show_prefit,
@@ -522,9 +538,10 @@ class NPRankingPlot:
     def plot(self, show_sigma:bool=True, show_prefit:bool=True, show_postfit:bool=True, sigma_bands:bool=False,
              sigma_lines:bool=True, shade:bool=True, correlation:bool=True, onesided:bool=True, relative:bool=False,
              theta_max:float=2, padding:int=7, height:float=1, spacing:float=0, display_poi:str=r"$\mu$", 
-             extra_text:str=None, elumi_label:bool=True, ranking_label:bool=True, energy:float=13, lumi:float=139,
-             n_rank=None, rank_per_plot=20, combine_pdf=True, threshold=0, ranking=True, fix_axis_scale=True,
-             outdir="ranking_plots", outname:str='ranking', style:Union[str, Dict]=DEFAULT_STYLE):
+             extra_text:str=None, elumi_label:bool=True, ranking_label:bool=True, energy:str=r"13 TeV", 
+             lumi:str=r"139 fb$^{-1}$",
+             status:str='int', n_rank=None, rank_per_plot=20, combine_pdf=True, threshold=0, ranking=True, 
+             fix_axis_scale=True, outdir="ranking_plots", outname:str='ranking', style:Union[str, Dict]=DEFAULT_STYLE):
         if isinstance(style, str):
             style = self.parse_style(style)
         if self.data is None:
@@ -551,7 +568,7 @@ class NPRankingPlot:
                              sigma_bands=sigma_bands, sigma_lines=sigma_lines, shade=shade, correlation=correlation,
                              onesided=onesided, relative=relative, theta_max=theta_max, padding=padding, height=height, 
                              spacing=spacing, display_poi=display_poi, extra_text=extra_text, elumi_label=elumi_label,
-                             ranking_label=ranking_label, energy=energy, lumi=lumi, r_start=start+1, style=style)
+                             ranking_label=ranking_label, energy=energy, lumi=lumi, status=status, r_start=start+1, style=style)
             if fix_axis_scale:
                 if nominal_xlim is None:
                     nominal_xlim = fig.get_axes()[1].get_xlim()
