@@ -354,7 +354,6 @@ def draw_atlas_label(axis, loc=(0.05, 0.95), fontsize=25, status:str='int',
                      extra_text:Optional[str]=None, dy:float=0.05,
                      transform_x:str='axis', transform_y:str='axis',
                      text_options:Optional[Dict]=None):
-    
     if status == "final":
         status_str = ""
     elif status == "int":
@@ -374,9 +373,10 @@ def draw_atlas_label(axis, loc=(0.05, 0.95), fontsize=25, status:str='int',
 
     elumi_text = []
     if energy is not None:
-        elumi_text.append(r"$\sqrt{s} = $ " + energy )
+        elumi_text.append(r"$\sqrt{s} = $" + energy )
     if lumi is not None:
         elumi_text.append(lumi)
+
     elumi_text = ", ".join(elumi_text)
     
     texts = []
@@ -390,8 +390,7 @@ def draw_atlas_label(axis, loc=(0.05, 0.95), fontsize=25, status:str='int',
         text_options = {}
     
     for text in texts:
-        _, _, ymin, _ = draw_text(axis, xmin, ymin - dy, text, transform_x=transform_x,
-                                  transform_y=transform_y, **text_options)
+        _, _, ymin, _ = draw_text(axis, xmin, ymin - dy, text, **text_options)
         
     return
 
